*株式会社ライトストーン
*Stata分析機能例題集　生存分析


*****Kaplan-Meier法による生存関数グラフの作成*****

*サンプルデータ「drug2」を入手
use https://www.stata-press.com/data/r16/drug2

*投薬の有無（drug）の違いによる生存率の時間変化をグラフ化
sts graph, by(drug) lost

*遅延組入のあるサンプルデータ「drug2b」を入手
use https://www.stata-press.com/data/r16/drug2b

*投薬の有無（drug）の違いによる生存率の時間変化をグラフ化
sts graph, by(drug) lost

*遅延組入と打ち切りを分けて表示する場合
sts graph, by(drug) lost enter

*サンプルデータ「drug2c」を入手し、グラフ作成
use https://www.stata-press.com/data/r16/drug2c
sts graph, by(drug) lost

*遅延組入と打ち切りを分けて表示する場合
sts graph, by(drug) lost enter


*****Nelson-Aalen累積ハザード関数のグラフ作成*****

*サンプルデータ「drug2」で、投薬の有無による累積ハザード関数をグラフ化
use https://www.stata-press.com/data/r16/drug2
stset, noshow
sts graph, cumhaz by(drug)

*打ち切りの人数を表示
sts graph, cumhaz by(drug) lost


**********ハザード関数のグラフ作成**********

*weighted カーネル平滑化を基にハザード関数を推定
sts graph, hazard by(drug)

*カーネル平滑化とバンド幅を調整
sts graph, hazard by(drug) kernel(gauss) width(5 7) title(Comparison of hazard function)


**********リスクテーブルを追加する**********

*リスクテーブルをグラフの下に追加
sts graph, by(drug) risktable

*凡例の位置を変更
sts graph, by(drug) risktable legend(ring(0) position(2) rows(2))

*リスクテーブルのラベル列を変更
sts graph, by(drug ) risktable(, order(1 "Placebo" 2 "Test drug"))

*ラベル列の文字を左揃えにする
sts graph, by(drug ) risktable(, order(1 "Placebo" 2 "Test drug") rowtitle(, justification(left)))

*リスクテーブルのタイトルとラベル列の行頭を揃える
sts graph, by(drug) risktable(, order(1 "Placebo" 2 "Test drug") rowtitle(, justification(left)) title(, at(rowtitle)))


**********Cox比例ハザードモデル**********

***打ち切りのないデータでCox回帰を行う***

*サンプルデータを入手し、データを確認
use https://www.stata-press.com/data/r16/kva
list

*フィット実行
stset failtime
stcox load bearings

*ハザード比ではなく係数を表示
stcox, nohr


***打ち切りのあるデータでCox 回帰を行う***

*データを入手してデータを整え、サマリーを確認
use https://www.stata-press.com/data/r16/drugtr
stset studytime, failure(died)
summarize

*フィット実行
stcox drug age

*5才年齢が変わる場合のリスクを計算
replace age = age/5

*フィット実行
stcox drug age, nolog


***時間で変化する共変量のあるデータでCox回帰を行う***

*データを入手
use https://www.stata-press.com/data/r16/stan3, clear

*フィット実行
stset t1, failure(died) id(id)
stcox age posttran surg year

